@@ -130,7 +130,7 @@ class DataLinspace(Data):
         """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
             for SciDataTool type, -1 will call the default constructor
-        - __init__ (init_dict = d) d must be a dictionnary with property names as keys
+        - __init__ (init_dict = d) d must be a dictionary with property names as keys
         - __init__ (init_str = s) s must be a string
         s is the file path to load
 
@@ -219,9 +219,11 @@ class DataLinspace(Data):
             return False
         return True
 
-    def compare(self, other, name="self"):
+    def compare(self, other, name="self", ignore_list=None):
         """Compare two objects and return list of differences"""
 
+        if ignore_list is None:
+            ignore_list = list()
         if type(other) != type(self):
             return ["type(" + name + ")"]
         diff_list = list()
@@ -242,6 +244,8 @@ class DataLinspace(Data):
             diff_list.append(name + ".is_components")
         if other._symmetries != self._symmetries:
             diff_list.append(name + ".symmetries")
+        # Filter ignore differences
+        diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
 
     def __sizeof__(self):
@@ -262,15 +266,23 @@ class DataLinspace(Data):
                 S += getsizeof(value) + getsizeof(key)
         return S
 
-    def as_dict(self, **kwargs):
+    def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
         """
         Convert this object in a json serializable dict (can be use in __init__).
+        type_handle_ndarray: int
+            How to handle ndarray (0: tolist, 1: copy, 2: nothing)
+        keep_function : bool
+            True to keep the function object, else return str
         Optional keyword input parameter is for internal use only
         and may prevent json serializability.
         """
 
         # Get the properties inherited from Data
-        DataLinspace_dict = super(DataLinspace, self).as_dict(**kwargs)
+        DataLinspace_dict = super(DataLinspace, self).as_dict(
+            type_handle_ndarray=type_handle_ndarray,
+            keep_function=keep_function,
+            **kwargs
+        )
         DataLinspace_dict["initial"] = self.initial
         DataLinspace_dict["final"] = self.final
         DataLinspace_dict["step"] = self.step
@@ -400,7 +412,7 @@ class DataLinspace(Data):
     is_components = property(
         fget=_get_is_components,
         fset=_set_is_components,
-        doc=u"""Boolean inidcating if the axis is components
+        doc=u"""Boolean indicating if the axis values are strings: True if strings
 
         :Type: bool
         """,
