@@ -3,7 +3,15 @@ from SciDataTool.Functions.parser import read_input_strings
 from SciDataTool.Functions.fft_functions import comp_fftn, comp_ifftn
 
 
-def get_along(self, *args, unit="SI", is_norm=False, axis_data=[], is_squeeze=True):
+def get_along(
+    self,
+    *args,
+    unit="SI",
+    is_norm=False,
+    axis_data=[],
+    is_squeeze=True,
+    is_magnitude=False
+):
     """Returns the ndarray of the field, using conversions and symmetries if needed.
     Parameters
     ----------
@@ -64,9 +72,9 @@ def get_along(self, *args, unit="SI", is_norm=False, axis_data=[], is_squeeze=Tr
     # Rebuild symmetries
     values = self.rebuild_symmetries(values, axes_list)
     # Interpolate over axis values
-    values = self.interpolate(values, axes_list, is_squeeze=is_squeeze)
+    values = self.interpolate(values, axes_list)
     # Conversions
-    values = self.convert(values, unit, is_norm, axes_list)
+    values = self.convert(values, unit, is_norm, is_squeeze, is_magnitude, axes_list)
     # Return axes and values
     return_dict = {}
     for axis_requested in axes_list:
