@@ -3,7 +3,16 @@
 from SciDataTool.Functions.Plot.plot_4D import plot_4D
 from SciDataTool.Functions.Plot.plot_3D import plot_3D
 from SciDataTool.Functions.Plot import unit_dict, norm_dict, axes_dict
-from numpy import where, meshgrid, unique, max as np_max, min as np_min, array2string
+from numpy import (
+    where,
+    meshgrid,
+    unique,
+    max as np_max,
+    min as np_min,
+    array2string,
+    linspace,
+    log10,
+)
 
 
 def plot_3D_Data(
@@ -154,8 +163,18 @@ def plot_3D_Data(
         result = self.get_along(arg_list, unit=unit, is_norm=is_norm)
     axes_list = result["axes_list"]
     axes_dict_other = result["axes_dict_other"]
-    Xdata = result[axes_list[0].name]
-    Ydata = result[axes_list[1].name]
+    if axes_list[0].is_components:
+        Xdata = linspace(
+            0, len(result[axes_list[0].name]) - 1, len(result[axes_list[0].name])
+        )
+    else:
+        Xdata = result[axes_list[0].name]
+    if axes_list[1].is_components:
+        Ydata = linspace(
+            0, len(result[axes_list[1].name]) - 1, len(result[axes_list[1].name])
+        )
+    else:
+        Ydata = result[axes_list[1].name]
     Zdata = result[self.symbol]
     if is_fft and not is_2D_view:
         X_flat = Xdata
@@ -196,13 +215,13 @@ def plot_3D_Data(
         name = axis.name
     title2 = "over " + name.lower()
     if axis.unit == "SI":
-        unit = unit_dict[axis.name]
-        xlabel = name.capitalize() + " [" + unit + "]"
+        axis_unit = unit_dict[axis.name]
+        xlabel = name.capitalize() + " [" + axis_unit + "]"
     elif axis.unit in norm_dict:
         xlabel = norm_dict[axis.unit]
     else:
-        unit = axis.unit
-        xlabel = name.capitalize() + " [" + unit + "]"
+        axis_unit = axis.unit
+        xlabel = name.capitalize() + " [" + axis_unit + "]"
     if (
         axis.name == "angle"
         and axis.unit == "°"
@@ -211,6 +230,11 @@ def plot_3D_Data(
         xticks = [i * round(np_max(axis.values) / 6) for i in range(7)]
     else:
         xticks = None
+    if axis.is_components:
+        xticklabels = result[axes_list[0].name]
+        xticks = Xdata
+    else:
+        xticklabels = None
 
     axis = axes_list[1]
     if axis.name in axes_dict:
@@ -219,13 +243,13 @@ def plot_3D_Data(
         name = axis.name
     title3 = " and " + axis.name.lower()
     if axis.unit == "SI":
-        unit = unit_dict[axis.name]
-        ylabel = name.capitalize() + " [" + unit + "]"
+        axis_unit = unit_dict[axis.name]
+        ylabel = name.capitalize() + " [" + axis_unit + "]"
     elif axis.unit in norm_dict:
         ylabel = norm_dict[axis.unit]
     else:
-        unit = axis.unit
-        ylabel = name.capitalize() + " [" + unit + "]"
+        axis_unit = axis.unit
+        ylabel = name.capitalize() + " [" + axis_unit + "]"
     if (
         axis.name == "angle"
         and axis.unit == "°"
@@ -234,15 +258,20 @@ def plot_3D_Data(
         yticks = [i * round(np_max(axis.values) / 6) for i in range(7)]
     else:
         yticks = None
+    if axis.is_components:
+        yticklabels = result[axes_list[1].name]
+        yticks = Xdata
+    else:
+        yticklabels = None
 
     title4 = " for "
     for axis in axes_list[2:]:
         if axis.unit == "SI":
-            unit = unit_dict[axis.name]
+            axis_unit = unit_dict[axis.name]
         elif axis.unit in norm_dict:
-            unit = norm_dict[axis.unit]
+            axis_unit = norm_dict[axis.unit]
         else:
-            unit = axis.unit
+            axis_unit = axis.unit
         title4 += (
             axis.name
             + "="
@@ -254,7 +283,7 @@ def plot_3D_Data(
             .replace("[", "")
             .replace("]", "")
             + " ["
-            + unit
+            + axis_unit
             + "], "
         )
     title5 = ""
@@ -285,7 +314,14 @@ def plot_3D_Data(
             else:
                 thresh = 0.02
 
-        indices = where(Z_flat > abs(thresh * np_max(Zdata)))[0]
+        if "dB" in unit:
+            indices = where(
+                Z_flat
+                > 10 * log10(thresh * self.normalizations["ref"]) + abs(np_max(Zdata))
+            )[0]
+        else:
+            indices = where(Z_flat > abs(thresh * np_max(Zdata)))[0]
+
         xticks = unique(X_flat[indices])
         yticks = unique(Y_flat[indices])
         if is_auto_range:
@@ -319,6 +355,8 @@ def plot_3D_Data(
                 title=title,
                 xticks=xticks,
                 yticks=yticks,
+                xticklabels=xticklabels,
+                yticklabels=yticklabels,
                 xlabel=xlabel,
                 ylabel=ylabel,
                 zlabel=zlabel,
@@ -355,6 +393,8 @@ def plot_3D_Data(
                 title=title,
                 xticks=xticks,
                 yticks=yticks,
+                xticklabels=xticklabels,
+                yticklabels=yticklabels,
                 xlabel=xlabel,
                 ylabel=ylabel,
                 zlabel=zlabel,
@@ -390,6 +430,8 @@ def plot_3D_Data(
                 title=title,
                 xticks=xticks,
                 yticks=yticks,
+                xticklabels=xticklabels,
+                yticklabels=yticklabels,
                 fig=fig,
                 ax=ax,
                 type_plot="pcolor",
@@ -425,6 +467,8 @@ def plot_3D_Data(
                 ylabel=ylabel,
                 zlabel=zlabel,
                 yticks=yticks,
+                xticklabels=xticklabels,
+                yticklabels=yticklabels,
                 type_plot="surf",
                 save_path=save_path,
                 is_show_fig=is_show_fig,
