@@ -27,12 +27,19 @@ def get_axis(self, axis, is_real):
     is_components = getattr(axis, "is_components", False)
     if is_components:
         values = axis.get_values()
-        if not self.extension in ["sum", "rss", "mean", "rms", "integrate"]:
-            self.extension = "list"
         if self.indices is not None:
-            self.values = values[self.indices]
+            if self.indices[0] == ":":
+                self.values = values
+                self.indices = list(range(len(values)))
+            else:
+                self.values = values[self.indices]
+                self.extension = "interval"
+        elif not self.extension in ["sum", "rss", "mean", "rms", "integrate", "list"]:
+            self.values = values
+            self.extension = "whole"
         else:
             self.values = values
+
     else:
         if self.extension == "pattern":
             if not self.is_pattern:
@@ -171,7 +178,8 @@ def get_axis(self, axis, is_real):
             if axis.normalizations.get(unit) == "indices":
                 values = array([i for i in range(len(values))])
             elif isinstance(axis.normalizations.get(unit), ndarray):
-                values = axis.normalizations.get(unit)
+                indices = [i for i in range(len(values))]
+                values = axis.normalizations.get(unit)[indices]
             else:
                 values = values / axis.normalizations.get(unit)
         else:
